# Diamond Project skeleton

Read more about Diamond here: https://github.com/iandennismiller/flask-diamond

## Usage

### clone the skeleton

```
git clone https://github.com/iandennismiller/diamond-project.git /tmp/diamond-project
```

### scaffold in the current directory

```
mrbob -w /tmp/diamond-project/skel
```

## Pre-requisites

```
pip install mr.bob
```
